@@ -2,8 +2,12 @@ require 'logger'
 require 'ffi'
 require 'thread'
 begin
-  require 'mime/types'
+  require 'mime/types/columnar'
 rescue LoadError
+  begin
+    require 'mime/types'
+  rescue LoadError
+  end
 end
 require 'tempfile'
 
