@@ -10,11 +10,24 @@ module Ethon
       layout :code, :msg_code, :easy_handle, :pointer, :data, MsgData
     end
 
+    class VersionInfoData < ::FFI::Struct
+      layout :curl_version, :uint8,
+        :version, :string,
+        :version_num, :int,
+        :host, :string,
+        :features, :int,
+        :ssl_version, :string,
+        :ssl_version_num, :long,
+        :libz_version, :string,
+        :protocols, :pointer
+    end
+
     # :nodoc:
     class FDSet < ::FFI::Struct
       if Curl.windows?
-        layout :fd_count, :u_int,
-               :fd_array, [:u_int, 64] # 2048 FDs
+        layout :fd_count, :uint,
+               # TODO: Make it future proof by dynamically grabbing FD_SETSIZE.
+               :fd_array, [:uint, 2048]
 
         def clear; self[:fd_count] = 0; end
       else
@@ -29,8 +42,13 @@ module Ethon
 
     # :nodoc:
     class Timeval < ::FFI::Struct
-      layout :sec, :time_t,
-             :usec, :suseconds_t
+      if Curl.windows?
+        layout :sec, :long,
+               :usec, :long
+      else
+        layout :sec, :time_t,
+               :usec, :suseconds_t
+      end
     end
   end
 end
