@@ -5,10 +5,15 @@ module Ethon
     # easy or multi interface.
     module Options
 
+      OPTION_STRINGS = { :easy => 'easy_options', :multi => 'multi_options' }.freeze
+      FOPTION_STRINGS = { :easy => 'EASY_OPTIONS', :multi => 'MULTI_OPTIONS' }.freeze
+      FTYPES = [:long, :string, :ffipointer, :callback, :debug_callback, :off_t]
+      FUNCS = Hash[*[:easy, :multi].zip([:easy, :multi].map { |t| Hash[*FTYPES.zip(FTYPES.map { |ft| "#{t}_setopt_#{ft}" }).flatten] }).flatten]
       # Sets appropriate option for easy, depending on value type.
       def set_option(option, value, handle, type = :easy)
-        raise NameError, "Ethon::Curls::Options unknown type #{type}." unless respond_to?("#{type.to_s.downcase}_options")
-        opthash=send("#{type.to_s.downcase}_options")
+        type = type.to_sym unless type.is_a?(Symbol)
+        raise NameError, "Ethon::Curls::Options unknown type #{type}." unless respond_to?(OPTION_STRINGS[type])
+        opthash=send(OPTION_STRINGS[type], nil)
         raise Errors::InvalidOption.new(option) unless opthash.include?(option)
 
         case opthash[option][:type]
@@ -90,8 +95,7 @@ module Ethon
             tv=((value<0) ? value.abs-1 : value)
             raise Errors::InvalidValue.new(option,value) unless tv<(1<<bits)
         end
-
-        send("#{type}_setopt_#{func}", handle, opthash[option][:opt], value)
+        send(FUNCS[type][func], handle, opthash[option][:opt], value)
       end
 
       OPTION_TYPE_BASE = {
@@ -174,25 +178,24 @@ module Ethon
         else
           raise ArgumentError, "Ethon::Curls::Options #{ftype} #{name} Expected no opts." unless opts.nil?
         end
-
-        opthash=const_get("#{ftype.to_s.upcase}_OPTIONS")
-        opthash[name]={:type=>type, :opt=>OPTION_TYPE_BASE[OPTION_TYPE_MAP[type]]+num, :opts=>opts}
+        opthash=const_get(FOPTION_STRINGS[ftype])
+        opthash[name] = { :type => type,
+                          :opt => OPTION_TYPE_BASE[OPTION_TYPE_MAP[type]] + num,
+                          :opts => opts }
       end
 
       def self.option_alias(ftype,name,*aliases)
-        opthash=const_get("#{ftype.to_s.upcase}_OPTIONS")
+        opthash=const_get(FOPTION_STRINGS[ftype])
         aliases.each { |a| opthash[a]=opthash[name] }
       end
 
       def self.option_type(type)
-        cname="#{type.to_s.upcase}_OPTIONS"
-        c=const_set(cname,{})
-        eval %Q<
-          def #{type.to_s.downcase}_options(rt=nil)
-            return #{cname}.map { |k,v| [k,v[:opt]] } if rt==:enum
-            #{cname}
-          end
-        >
+        cname = FOPTION_STRINGS[type]
+        const_set(cname, {})
+        define_method(OPTION_STRINGS[type]) do |rt|
+          return Ethon::Curls::Options.const_get(cname).map { |k, v| [k, v[:opt]] } if rt == :enum
+          Ethon::Curls::Options.const_get(cname)
+        end
       end
 
       # Curl multi options, refer
@@ -415,7 +418,7 @@ module Ethon
       option_alias :easy, :keypasswd, :sslkeypasswd
       option :easy, :sslengine, :string, 89
       option :easy, :sslengine_default, :none, 90
-      option :easy, :sslversion, :enum, 32, [:default, :tlsv1, :sslv2, :sslv3]
+      option :easy, :sslversion, :enum, 32, [:default, :tlsv1, :sslv2, :sslv3, :tlsv1_0, :tlsv1_1, :tlsv1_2]
       option :easy, :ssl_verifypeer, :bool, 64
       option :easy, :cainfo, :string, 65
       option :easy, :issuercert, :string, 170
